pub(crate) enum Command {
Init {
path: PathBuf,
},
Build {
entries: Vec<PathBuf>,
open: Option<Option<String>>,
frozen: bool,
reproducible: bool,
},
Watch {
entry: PathBuf,
},
Check {
entries: Vec<PathBuf>,
},
Fmt {
path: PathBuf,
},
Test,
Profile {
entry: PathBuf,
},
Clean,
Package {
entry: PathBuf,
},
}Variants
Init
Initialise a new Mosaic project in the current directory.
Build
Build the project to its declared outputs.
Fields
Watch
Watch sources and rebuild on change (manifest 8).
Check
Type-check and validate without producing output.
Fmt
Format .mos sources (manifest 18).
Test
Run document and package tests (manifest 28).
Profile
Profile a build and report layout hot spots (manifest 16).
Clean
Remove build artefacts and the local cache.
Package
Bundle a project into a .mosaicbundle archive (manifest 15.3).